#
# Main file for fish command completions. This file contains various
# common helper functions for the command completions. All actual
# completions are located in the completions subdirectory.
#
# share/config.fish, generated from share/config.fish.in by the Makefile. DO NOT MANUALLY EDIT THIS FILE!

#
# Set default search paths for completions and shellscript functions
# unless they already exist
#

set -l configdir ~/.config
if set -q XDG_CONFIG_HOME
	set configdir $XDG_CONFIG_HOME
end

if not set -q __fish_datadir
	set -U __fish_datadir /usr/share/fish
end

if not set -q fish_function_path 
	set -U fish_function_path $configdir/fish/functions    /etc/fish/functions    /usr/share/fish/functions 
end

if not set -q fish_complete_path 
	set -U fish_complete_path $configdir/fish/completions  /etc/fish/completions  /usr/share/fish/completions 
end

set __fish_help_dir /usr/share/doc/fish

# This is a Solaris-specific test to modify the PATH so that
# Posix-conformant tools are used by default.

if test -d /usr/xpg4/bin
	if not contains /usr/xpg4/bin $PATH
		set PATH /usr/xpg4/bin $PATH 
	end
end   


#
# Make sure there are no invalid entries in the PATH
#

if status --is-interactive
	set -l new_path
	for i in $PATH
		if not test -d $i
			printf (_ '%s: Warning: The directory %s has been removed from your PATH because it does not exist\n') fish $i
		else
			set new_path $new_path $i
		end
	end

	set PATH $new_path
end

#
# Add a few common directories to path, if they exists. Note that pure
# console programs like makedep sometimes live in /usr/X11R6/bin, so we
# want this even for text-only terminals.
#

set -l path_list /bin /usr/bin /usr/X11R6/bin /usr/bin 

# Root should also have the sbin directories in the path
if test "$USER" = root
	set path_list $path_list /sbin /usr/sbin /usr/local/sbin
end

# Make a regular expression that matches any component in the PATH. A
# trailing slash is ok. The sed call is to remove the last '|'.  
set -l tmp (printf "%s" \^$PATH'/?$|')
set -l path_regexp \((echo $tmp | sed -e "s/.\$//")\)

for i in (printf "%s\n" $path_list|sgrep -E -v $path_regexp)
	if test -d $i
		set PATH $PATH $i
	end
end


if status --is-interactive
	. config_interactive.fish
end
